@@ -57,10 +57,9 @@ def build_image(file, size, pre_key, crop=False, quality=90, cache=False, unique
     """
     Builds a resized image based off of the original image.
     """
-
     try:
         quality = int(quality)
-    except:
+    except TypeError:
         quality = 90
 
     if settings.USE_S3_STORAGE:
@@ -72,21 +71,30 @@ def build_image(file, size, pre_key, crop=False, quality=90, cache=False, unique
         else:
             raise Http404
 
-    # handle infamous error
-    # IOError: cannot write mode P as JPEG
-    if image.mode != "RGB":
-        image = image.convert("RGB")
+    image_options = {'quality': quality}
+    if image.format == 'GIF':
+        image_options['transparency'] = 0
+
+    format = image.format
+    if image.format in ('GIF', 'PNG'):
+        if image.mode != "RGBA":
+            image = image.convert("RGBA")
+        image.format = format  # this is lost in conversion
+
+    elif image.format == 'JPEG':
+        # handle infamous error
+        # IOError: cannot write mode P as JPEG
+        if image.mode != "RGB":
+            image = image.convert("RGB")
 
     if crop:
         image = image_rescale(image, size)  # thumbnail image
     else:
+        format = image.format
         image = image.resize(size, Image.ANTIALIAS)  # resize image
+        image.format = format
 
-    # mission: get binary
-    output = StringIO()
-    image.save(output, "JPEG", quality=quality)
-    binary = output.getvalue()  # mission accomplished
-    output.close()
+    binary = get_image_binary(image, **image_options)
 
     if cache:
         key = generate_image_cache_key(file, size, pre_key, crop, unique_key, quality, constrain)
@@ -95,6 +103,20 @@ def build_image(file, size, pre_key, crop=False, quality=90, cache=False, unique
     return binary
 
 
+def get_image_binary(image, **options):
+    """
+    Returns image binary
+    """
+    image.format = image.format or 'JPEG'
+
+    output = StringIO()
+    image.save(output, image.format, **options)
+    binary = output.getvalue()
+    output.close()
+
+    return binary
+
+
 def validate_image_size(size):
     """
     We cap our image sizes to avoid processor overload
@@ -111,7 +133,7 @@ def validate_image_size(size):
         else:
             new_size.append(item[0])
 
-    return new_size
+    return tuple(new_size)
 
 
 def aspect_ratio(image_size, new_size, constrain=False):
